# `pose_python` - Position and Orientation Python Library

Repo to help handling 3D and 2D poses as well as transformations between reference frames.

## Documentation
Visit page: <https://johnhal.gitlab.io/pose_python>

## Todos

- [ ] Finish tests of `Rotation2D` class
